// import the required GraphQL Types
const {
    GraphQLObjectType,
    GraphQLInt,
    GraphQLString,
    GraphQLList,
    GraphQLID,
    GraphQLInputObjectType
  } = require('graphql');

  var GraphQLDate = require('graphql-date')

const jwt = require("jsonwebtoken")
const { createJwtToken } = require("../../util/auth")

const  db  = require('../../models');

const Ad = db.ads;
const AdType = require('./../types/adType')  


//delete one Ad
exports.deleteAdMutation = {
    type : AdType,
    description: 'Delete an Ad',
    args:{
        id : {
            type:GraphQLID
        }
    },
    async resolve (parent, args, { verifiedUser } ) {
        console.log(verifiedUser)
        if (!verifiedUser) {
        throw new Error("Unauthenticated")
        }
        const adDeleted = await Ad.findOneAndDelete({
            _id: args.id,
            id_user: verifiedUser._id,
          })
          if (!adDeleted) {
            throw new Error("No ad with the given ID found for the user")
          }
      
          return "ad Deleted"
    }
}; 




//use it multiple times
const ad = {
    titre: {
        type: GraphQLString
    },
    slug: {
      type: GraphQLString
  },
  type: {
      type: GraphQLString
  },
  statusPublication: {
      type: GraphQLString
  },
  statusBien: {
      type: GraphQLString
  },
  description: {
      type: GraphQLString
  },
  prix: {
      type: GraphQLInt
  },
  //error
  date: {
      type: GraphQLDate
  },
  id_user : {
    type: GraphQLString
  }, 
  images:{
      type: GraphQLList(GraphQLString)
  },
}

exports.createAdMutation = {
    type : AdType,
    description: 'Create an Ad',
    args : {
        titre: {
            type: GraphQLString
        },
        slug: {
          type: GraphQLString
        },
        type: {
            type: GraphQLString
        },
        statusPublication: {
            type: GraphQLString
        },
        statusBien: {
            type: GraphQLString
        },
        description: {
            type: GraphQLString
        },
        prix: {
            type: GraphQLInt
        },
        date: {
            type: GraphQLDate
        }, 
        images:{
            type: GraphQLList(GraphQLString)
        },
    },
    resolve(parent, args, req ){
        console.log("Verified User: ", req.verifiedUser)
        if (!req.verifiedUser) {
        throw new Error("Unauthorized")
        }
        args.id_user = req.verifiedUser._id
        const ad = new Ad(args)
          return ad.save()
    } 
}; 

  


exports.updateAdMutation = {
    type : AdType,
    description: 'Update an Ad',
    args:{
        id:{
            type: GraphQLString
        },
        titre: {
            type: GraphQLString
        },
        slug: {
          type: GraphQLString
      },
      type: {
          type: GraphQLString
      },
      statusPublication: {
          type: GraphQLString
      },
      statusBien: {
          type: GraphQLString
      },
      description: {
          type: GraphQLString
      },
      prix: {
          type: GraphQLInt
      },
      date: {
          type: GraphQLDate
      },
      images:{
          type: GraphQLList(GraphQLString)
      },
    },
    async resolve(parent, args, { verifiedUser }) {
        if (!verifiedUser) {
            throw new Error("Unauthenticated")
          }
        const updateAd = await Ad.findOneAndUpdate({ _id: args.id, id_user: verifiedUser._id},args)
        if (!updateAd) {
            throw new Error("No Ad with the given ID found for the user")
          }
          return args
    } 
};
